==> srimaticket_090223_07PM.zip: srimaticket/header.php <==
<?php 
    session_start();
    //echo "<pre>";print_r($_SESSION);
    if (!(isset($_SESSION['login']))) {
	    header('location:index.php');
    }
    
    require('config/Database.php');
    $db = Database::getInstance();
    $mysqli = $db->getConnection();
    
    $query = "SELECT * FROM students WHERE reg_mobile=".$_SESSION['session_mobile_number'];
    $stddata= $mysqli->query($query);
    if ($stddata->num_rows > 0) {
        while($row = $stddata->fetch_assoc()){
            $username = $row["first_name"].' '.$row["last_name"];
            $sid = $row["sid"];
            $email = $row["reg_email"];
            $standard = $row["standard"];
            $division = $row["division"];
            $aadhar_id = $row["aadhar_id"];
            $mother_tongue = $row["mother_tongue"];
            $caste = $row["caste"];
            $sub_caste = $row["sub_caste"];   
        }
    }
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Srima Application</title>
    <!-- <link href="bower_components/bootstrap/dist/css/bootstrap.min.css" rel="stylesheet">         -->
    <link rel="stylesheet" href="dist/css/bootstrap.min.css" /> 
    <link href="dist/css/sb-admin-2.css" rel="stylesheet">    
    <link rel="stylesheet" type="text/css" href="dist/css/style.css">
    <link rel="stylesheet" type="text/css" href="dist/css/style2.css">
    <link rel="stylesheet" href="dist/css/responsive.css" /> 
	<link href="https://fonts.googleapis.com/css2?family=Mukta:wght@300;400;500;600;700;800&display=swap" rel="stylesheet">    
    
</head>
<body>

    <div class="fixed-header">
        <header class="main-header">
            <div class="auto-container">
                <div class="row">
                    <div class="col-12">
                        <nav class="navbar main-menu">
                            <div class="logo">
                                <a href="dashboard.php">
                                    <img src="images/srima-logo.png" alt="">
                                </a>
                            </div>
                            <div class="center-text">
                                <span>Welcome, <?= $username ?></span>
                            </div>
                            <div class="login-user-dropdown">
                                 <a href="logout.php"><img src="images/logout.png" alt=""></a>
                            </div>
                        </nav>
                    </div>
                </div>
            </div>
        </header>
    </div>
    <div class="content-body-section">

==> srimaticket_100223_02PM.zip: srimaticket/header.php <==
<?php 
    session_start();
    //echo "<pre>";print_r($_SESSION);
    if (!(isset($_SESSION['login']))) {
	    header('location:index.php');
    }
    
    require('config/Database.php');
    $db = Database::getInstance();
    $mysqli = $db->getConnection();
    
    $query = "SELECT * FROM students WHERE reg_mobile=".$_SESSION['session_mobile_number'];
    $stddata= $mysqli->query($query);
    if ($stddata->num_rows > 0) {
        while($row = $stddata->fetch_assoc()){
            $username = $row["first_name"].' '.$row["last_name"];
            $sid = $row["sid"];
            $email = $row["reg_email"];
            $standard = $row["standard"];
            $division = $row["division"];
            $aadhar_id = $row["aadhar_id"];
            $mother_tongue = $row["mother_tongue"];
            $caste = $row["caste"];
            $sub_caste = $row["sub_caste"];   
        }
    }
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Srima Application</title>
    <!-- <link href="bower_components/bootstrap/dist/css/bootstrap.min.css" rel="stylesheet">         -->
    <link rel="stylesheet" href="dist/css/bootstrap.min.css" /> 
    <link href="dist/css/sb-admin-2.css" rel="stylesheet">    
    <link rel="stylesheet" type="text/css" href="dist/css/style.css">
    <link rel="stylesheet" type="text/css" href="dist/css/style2.css">
    <link rel="stylesheet" href="dist/css/responsive.css" /> 
	<link href="https://fonts.googleapis.com/css2?family=Mukta:wght@300;400;500;600;700;800&display=swap" rel="stylesheet">    
    
</head>
<body>

    <div class="fixed-header">
        <header class="main-header">
            <div class="auto-container">
                <div class="row">
                    <div class="col-12">
                        <nav class="navbar main-menu">
                            <div class="logo">
                                <a href="dashboard.php">
                                    <img src="images/srima-logo.png" alt="">
                                </a>
                            </div>
                            <div class="center-text">
                                <span>Welcome, <?= $username ?></span>
                            </div>
                            <div class="login-user-dropdown">
                                 <a href="logout.php"><img src="images/logout.svg" alt=""></a>
                            </div>
                        </nav>
                    </div>
                </div>
            </div>
        </header>
    </div>
    <div class="content-body-section">
